Django-CheetahTemplate Example
==============================

Example of using CheetahTemplate3 in Django.

Install django-cheetahtemplate and run
``./manage.py runserver localhost:8080``.
Point browser to ``http://localhost:8080`` or
``http://localhost:8080/xxx``.
Stop the server with ``Ctrl+C``.
